@@ -104,6 +104,7 @@ class Verification(models.Model):
             context = ({
                 'username': get_username,
                 'code': code_num,
+                'domain': SaveDomain.objects.all().order_by('-id').first()
             })
             text_content = render_to_string('account/email.txt', context)
             html_content = render_to_string('account/email.html', context)
@@ -121,5 +122,11 @@ class Verification(models.Model):
 
     
 
-    
-    
\ No newline at end of file
+class SaveDomain(models.Model):
+    domain = models.CharField(max_length=255)
+
+    def get_domain(self, *args, **kwargs):
+        if self.domain:
+            return self.domain
+        else:
+            return None
\ No newline at end of file
